@@ -7,10 +7,7 @@ Usage::
     import boto3
     from mypy_boto3_iot1click_devices import IoT1ClickDevicesServiceClient
 
-    session = boto3.Session()
-
     client: IoT1ClickDevicesServiceClient = boto3.client("iot1click-devices")
-    session_client: IoT1ClickDevicesServiceClient = session.client("iot1click-devices")
     ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
