@@ -7,7 +7,7 @@ Usage::
     import boto3
 
     from mypy_boto3_iot1click_devices import IoT1ClickDevicesServiceClient
-    from mypy_boto3_iot1click_devices import (
+    from mypy_boto3_iot1click_devices.paginator import (
         ListDeviceEventsPaginator,
         ListDevicesPaginator,
     )
